==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fr_tu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Affichage en cases',
	'affichage_documents_en_grand' => 'Affichage en grand',
	'affichage_documents_en_liste_compacte' => 'Affichage en liste compacte',
	'aucun_audio' => 'Aucune bande-son',
	'aucun_document' => 'Aucun document',
	'aucun_file' => 'Aucun document',
	'aucun_image' => 'Aucune image',
	'aucun_video' => 'Aucune séquence',
	'aucune_utilisation' => 'Ce document n’est pas utilisé',
	'aucune_vignette' => 'Aucune vignette',

	// B
	'bouton_ajouter_document' => 'Ajouter un document',
	'bouton_ajouter_image' => 'Ajouter une image',
	'bouton_ajouter_image_document' => 'Ajouter une image ou un document',
	'bouton_attacher_document' => 'Attacher',
	'bouton_copier_local' => 'Copier dans le site',
	'bouton_download_depuis' => 'depuis :',
	'bouton_download_local' => 'mon ordinateur',
	'bouton_download_par_ftp' => 'le serveur',
	'bouton_download_par_mediatheque' => 'la médiathèque',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Détacher',
	'bouton_enlever_supprimer_document' => 'Supprimer',
	'bouton_enlever_supprimer_document_confirmation' => 'Es-tu sûr de vouloir supprimer le document ?',
	'bouton_modifier_document' => 'Modifier',
	'bouton_parcourir' => 'Parcourir…',
	'bouton_refresh_document' => 'Rafraîchir le document',
	'bouton_remplacer_document' => 'Remplacer ce document',
	'bouton_remplacer_image' => 'Remplacer cette image',
	'bouton_remplacer_image_document' => 'Remplacer par une image ou un document',
	'bouton_supprimer' => 'Supprimer',
	'bouton_supprimer_tous_orphelins' => 'Supprimer tous les documents inutilisés',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Es-tu sûr de vouloir supprimer @nb@ documents inutilisés ?',
	'bouton_upload' => 'Téléverser',

	// D
	'des_audios' => '@nb@ bandes-son',
	'des_documents' => '@nb@ documents',
	'des_files' => '@nb@ documents',
	'des_images' => '@nb@ images',
	'des_utilisations' => '@nb@ utilisations',
	'des_videos' => '@nb@ séquences',
	'descriptif' => 'Description',
	'details_document' => 'Détails',
	'details_document_afficher_masquer' => 'Afficher / masquer les détails du document',
	'document_attache_succes' => 'Le document a bien été ajouté',
	'document_copie_locale_succes' => 'Le fichier a bien été copié dans le site',
	'document_installe_succes' => 'Le fichier a bien été chargé',
	'document_vu' => 'Inséré dans le texte',
	'documents' => 'Médiathèque',
	'documents_brises' => 'Brisés',
	'documents_distants' => 'Distants',
	'documents_locaux' => 'Locaux',
	'documents_non_publies' => 'Non publiés',
	'documents_orphelins' => 'Inutilisés',
	'documents_publies' => 'Publiés',
	'documents_tous' => 'Tous',
	'double_clic_inserer_doc' => 'Double-cliques pour insérer ce raccourci dans le texte',

	// E
	'entree_dimensions' => 'Dimensions :',
	'entree_titre_document' => 'Titre du document :',
	'entree_titre_image' => 'Titre de l’image :',
	'erreur_aucun_document' => 'Ce document n’existe pas dans la médiathèque',
	'erreur_aucun_fichier' => 'Aucun fichier n’a été trouvé',
	'erreur_autorisation' => 'Échec de l’autorisation.',
	'erreur_chemin_distant' => 'Le fichier distant @nom@ n’a pas pu être trouvé',
	'erreur_chemin_ftp' => 'Le fichier indiqué n’a pas été trouvé sur le serveur',
	'erreur_copie_fichier' => 'Impossible de copier le fichier @nom@',
	'erreur_deplacement_impossible' => 'Déplacement impossible.',
	'erreur_dossier_tmp_manquant' => 'Un dossier temporaire est manquant pour télécharger les fichiers',
	'erreur_ecriture_fichier' => 'Erreur lors de l’écriture du fichier sur le disque',
	'erreur_format_fichier_image' => 'Le format de @nom@ ne convient pas pour une image',
	'erreur_indiquez_un_fichier' => 'Indiques un fichier !',
	'erreur_insertion_document_base' => 'Impossible d’enregistrer le document @fichier@ en base de données',
	'erreur_objet_absent' => 'Informations reçues incomplètes.',
	'erreur_suppression_vignette' => 'Erreur lors de la suppression de la vignette',
	'erreur_upload_type_interdit' => 'Le téléchargement des fichiers du type de @nom@ n’est pas autorisé',
	'erreur_upload_vignette' => 'Erreur lors du chargement de la vignette @nom@',
	'erreurs' => '@nb@ erreurs',
	'erreurs_voir' => 'Voir les @nb@ erreurs',

	// F
	'fichier_distant' => 'Fichier distant',
	'fichier_manquant' => 'Fichier manquant',
	'fichier_modifie' => 'Le fichier a été modifié. Cliquez sur enregistrer.',
	'format_date_incorrect' => 'La date ou l’heure sont incorrectes',

	// I
	'icone_creer_document' => 'Ajouter un document',
	'id' => 'ID',
	'image_tourner_180' => 'Rotation 180°',
	'image_tourner_droite' => 'Rotation 90° à droite',
	'image_tourner_gauche' => 'Rotation 90° à gauche',
	'info_alt' => 'Description du contenu de l’image quand elle n’est pas visible, en complément du titre.',
	'info_dimensions_image' => 'Dimensions',
	'info_doc_max_poids' => 'Les documents doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Ce document n’est pas disponible',
	'info_documents' => 'Documents',
	'info_duree' => 'Durée',
	'info_gauche_numero_document' => 'DOCUMENT NUMÉRO',
	'info_hauteur' => 'Hauteur',
	'info_heure' => 'Heure',
	'info_illustrations' => 'Illustrations',
	'info_image_max_poids' => 'Les images doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_image_max_taille' => 'Les images doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_image_min_taille' => 'Les images doivent obligatoirement faire au moins @mini@ (ce fichier fait @actuel@).',
	'info_inclusion_directe' => 'Inclusion directe :',
	'info_inclusion_vignette' => 'Inclusion de la vignette :',
	'info_installer_tous_documents' => 'Installer tous les documents',
	'info_largeur' => 'Largeur',
	'info_logo_max_taille' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_mode' => 'Mode',
	'info_modifier_document' => 'Modifier le document',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Référencer un document sur l’internet :',
	'info_resolution_image' => 'Résolution',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Sans vignette',
	'info_statut_document' => 'Ce document est :',
	'info_taille' => 'Poids',
	'info_telecharger' => 'Télécharger depuis ton ordinateur :',
	'info_utilisation' => 'Utilisation(s)',
	'infos' => 'Infos techniques',
	'inserer_raccourci' => 'Insérer ce raccourci dans le texte',
	'item_autoriser_selectionner_date_en_ligne' => 'Permettre de modifier la date de chaque document',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La date des documents est celle de leur ajout sur le site',

	// L
	'label_activer_document_objets' => 'Activer le téléversement pour les contenus :',
	'label_alt' => 'Alternative textuelle (alt)',
	'label_apercu' => 'Aperçu',
	'label_caracteristiques' => 'Caractéristiques',
	'label_credits' => 'Crédits',
	'label_fichier' => 'Fichier',
	'label_fichier_vignette' => 'Vignette',
	'label_paginer_par' => 'Paginer par :',
	'label_parents' => 'Ce document est lié à',
	'label_refdoc_joindre' => 'Document numéro',
	'label_titre_mimetype' => 'Type de fichier',
	'lien_tout_desordonner' => 'Réinitialiser l’ordre',
	'lien_tout_desordonner_verif' => 'L’ordre définit pour cette liste de documents sera réinitialisé. Es-tu sûr ?',
	'lien_tout_enlever' => 'Tout détacher',
	'lien_tout_enlever_verif' => 'Veux-tu détacher tous les documents ?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Bandes-son',
	'media_file' => 'Autres',
	'media_image' => 'Images',
	'media_video' => 'Séquences',
	'miniature_automatique_active' => 'SPIP génèrera automatiquement une miniature de l’image',

	// N
	'nb_documents_attache_succes' => '@nb@ documents ont bien été ajoutés',
	'nb_documents_installe_succes' => '@nb@ fichiers chargés avec succès',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documents',
	'ordonner_ce_document' => 'Ordonner ce document',

	// P
	'par_date' => 'Date',
	'par_hauteur' => 'Hauteur',
	'par_id' => 'ID',
	'par_largeur' => 'Largeur',
	'par_taille' => 'Poids',
	'par_titre' => 'Titre',

	// T
	'texte_documents_joints' => 'Tu peux activer l’interface d’ajout de documents (fichiers bureautiques, images, multimédia, etc.) aux articles, rubriques et autres. Ces fichiers peuvent ensuite être référencés dans le texte, ou affichés séparément.',
	'texte_documents_joints_2' => 'Ce réglage n’empêche pas le téléversement d’images dans les articles ni l’insertion de document directement dans les textes des contenus.',
	'titre_documents_joints' => 'Documents joints',
	'titre_page_documents_edit' => 'Modifier le document : @titre@',
	'tous_les_medias' => 'Tous les médias',
	'tout_dossier_upload' => 'Tout le dossier @upload@',
	'tout_voir' => 'Tout voir',

	// U
	'un_audio' => '1 bande-son',
	'un_document' => '1 document',
	'un_file' => '1 document',
	'un_image' => '1 image',
	'un_video' => '1 séquence',
	'une_utilisation' => '1 utilisation',
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Le fichier que tu proposes d’installer est un fichier Zip.',
	'upload_fichier_zip_texte2' => 'Ce fichier peut être :',
	'upload_info_mode_document' => 'Déposer dans le portfolio',
	'upload_info_mode_image' => 'Retirer du portfolio',
	'upload_limit' => 'Ce fichier est trop gros pour le serveur ; la taille maximum autorisée en <i>upload</i> est de @max@.',
	'upload_zip_conserver' => 'Conserver l’archive après extraction',
	'upload_zip_decompacter' => 'décompressé et chaque élément qu’il contient installé sur le site. Les fichiers qui seront alors installés sur le site sont :',
	'upload_zip_mode_document' => 'Déposer toutes les images dans le portfolio',
	'upload_zip_telquel' => 'installé tel quel, en tant qu’archive compressée Zip ;',
	'upload_zip_titrer' => 'Titrer selon le nom des fichiers',

	// V
	'verifier_documents_brises' => 'Vérifier les fichiers manquants',
	'verifier_documents_inutilises' => 'Vérifier les liens des documents',
	'vignette_supprimee' => 'La vignette a été supprimée'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_fr_tu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'Affichage en cases',
	'affichage_documents_en_grand' => 'Affichage en grand',
	'affichage_documents_en_liste_compacte' => 'Affichage en liste compacte',
	'aucun_audio' => 'Aucune bande-son',
	'aucun_document' => 'Aucun document',
	'aucun_file' => 'Aucun document',
	'aucun_image' => 'Aucune image',
	'aucun_video' => 'Aucune séquence',
	'aucune_utilisation' => 'Ce document n’est pas utilisé',
	'aucune_vignette' => 'Aucune vignette',

	// B
	'bouton_ajouter_document' => 'Ajouter un document',
	'bouton_ajouter_image' => 'Ajouter une image',
	'bouton_ajouter_image_document' => 'Ajouter une image ou un document',
	'bouton_attacher_document' => 'Attacher',
	'bouton_copier_local' => 'Copier dans le site',
	'bouton_download_depuis' => 'depuis :',
	'bouton_download_local' => 'mon ordinateur',
	'bouton_download_par_ftp' => 'le serveur',
	'bouton_download_par_mediatheque' => 'la médiathèque',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Détacher',
	'bouton_enlever_supprimer_document' => 'Supprimer',
	'bouton_enlever_supprimer_document_confirmation' => 'Es-tu sûr de vouloir supprimer le document ?',
	'bouton_modifier_document' => 'Modifier',
	'bouton_parcourir' => 'Parcourir…',
	'bouton_refresh_document' => 'Rafraîchir le document',
	'bouton_remplacer_document' => 'Remplacer ce document',
	'bouton_remplacer_image' => 'Remplacer cette image',
	'bouton_remplacer_image_document' => 'Remplacer par une image ou un document',
	'bouton_supprimer' => 'Supprimer',
	'bouton_supprimer_tous_orphelins' => 'Supprimer tous les documents inutilisés',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Es-tu sûr de vouloir supprimer @nb@ documents inutilisés ?',
	'bouton_upload' => 'Téléverser',

	// D
	'des_audios' => '@nb@ bandes-son',
	'des_documents' => '@nb@ documents',
	'des_files' => '@nb@ documents',
	'des_images' => '@nb@ images',
	'des_utilisations' => '@nb@ utilisations',
	'des_videos' => '@nb@ séquences',
	'descriptif' => 'Description', # MODIF
	'details_document' => 'Détails',
	'details_document_afficher_masquer' => 'Afficher / masquer les détails du document',
	'document_attache_succes' => 'Le document a bien été ajouté',
	'document_copie_locale_succes' => 'Le fichier a bien été copié dans le site',
	'document_installe_succes' => 'Le fichier a bien été chargé',
	'document_vu' => 'Inséré dans le texte',
	'documents' => 'Médiathèque',
	'documents_brises' => 'Brisés',
	'documents_distants' => 'Distants',
	'documents_locaux' => 'Locaux',
	'documents_non_publies' => 'Non publiés',
	'documents_orphelins' => 'Inutilisés',
	'documents_publies' => 'Publiés',
	'documents_tous' => 'Tous',
	'double_clic_inserer_doc' => 'Double-cliques pour insérer ce raccourci dans le texte',

	// E
	'entree_dimensions' => 'Dimensions :',
	'entree_titre_document' => 'Titre du document :',
	'entree_titre_image' => 'Titre de l’image :',
	'erreur_aucun_document' => 'Ce document n’existe pas dans la médiathèque',
	'erreur_aucun_fichier' => 'Aucun fichier n’a été trouvé',
	'erreur_autorisation' => 'Échec de l’autorisation.',
	'erreur_chemin_distant' => 'Le fichier distant @nom@ n’a pas pu être trouvé',
	'erreur_chemin_ftp' => 'Le fichier indiqué n’a pas été trouvé sur le serveur',
	'erreur_copie_fichier' => 'Impossible de copier le fichier @nom@',
	'erreur_deplacement_impossible' => 'Déplacement impossible.',
	'erreur_dossier_tmp_manquant' => 'Un dossier temporaire est manquant pour télécharger les fichiers',
	'erreur_ecriture_fichier' => 'Erreur lors de l’écriture du fichier sur le disque',
	'erreur_format_fichier_image' => 'Le format de @nom@ ne convient pas pour une image',
	'erreur_indiquez_un_fichier' => 'Indiques un fichier !',
	'erreur_insertion_document_base' => 'Impossible d’enregistrer le document @fichier@ en base de données',
	'erreur_objet_absent' => 'Informations reçues incomplètes.',
	'erreur_suppression_vignette' => 'Erreur lors de la suppression de la vignette',
	'erreur_upload_type_interdit' => 'Le téléchargement des fichiers du type de @nom@ n’est pas autorisé',
	'erreur_upload_vignette' => 'Erreur lors du chargement de la vignette @nom@',
	'erreurs' => '@nb@ erreurs',
	'erreurs_voir' => 'Voir les @nb@ erreurs',

	// F
	'fichier_distant' => 'Fichier distant',
	'fichier_manquant' => 'Fichier manquant',
	'fichier_modifie' => 'Le fichier a été modifié. Cliquez sur enregistrer.',
	'format_date_incorrect' => 'La date ou l’heure sont incorrectes',

	// I
	'icone_creer_document' => 'Ajouter un document',
	'id' => 'ID',
	'image_tourner_180' => 'Rotation 180°',
	'image_tourner_droite' => 'Rotation 90° à droite',
	'image_tourner_gauche' => 'Rotation 90° à gauche',
	'info_alt' => 'Description du contenu de l’image quand elle n’est pas visible, en complément du titre.',
	'info_dimensions_image' => 'Dimensions',
	'info_doc_max_poids' => 'Les documents doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_document' => 'Document',
	'info_document_indisponible' => 'Ce document n’est pas disponible',
	'info_documents' => 'Documents',
	'info_duree' => 'Durée',
	'info_gauche_numero_document' => 'DOCUMENT NUMÉRO',
	'info_hauteur' => 'Hauteur',
	'info_heure' => 'Heure',
	'info_illustrations' => 'Illustrations',
	'info_image_max_poids' => 'Les images doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_image_max_taille' => 'Les images doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_image_min_taille' => 'Les images doivent obligatoirement faire au moins @mini@ (ce fichier fait @actuel@).',
	'info_inclusion_directe' => 'Inclusion directe :',
	'info_inclusion_vignette' => 'Inclusion de la vignette :',
	'info_installer_tous_documents' => 'Installer tous les documents',
	'info_largeur' => 'Largeur',
	'info_logo_max_taille' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
	'info_mode' => 'Mode',
	'info_modifier_document' => 'Modifier le document',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Référencer un document sur l’internet :',
	'info_resolution_image' => 'Résolution',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Sans vignette',
	'info_statut_document' => 'Ce document est :',
	'info_taille' => 'Poids',
	'info_telecharger' => 'Télécharger depuis ton ordinateur :',
	'info_utilisation' => 'Utilisation(s)',
	'infos' => 'Infos techniques',
	'inserer_raccourci' => 'Insérer ce raccourci dans le texte',
	'item_autoriser_selectionner_date_en_ligne' => 'Permettre de modifier la date de chaque document',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La date des documents est celle de leur ajout sur le site',

	// L
	'label_activer_document_objets' => 'Activer le téléversement pour les contenus :',
	'label_alt' => 'Alternative textuelle (alt)',
	'label_apercu' => 'Aperçu',
	'label_caracteristiques' => 'Caractéristiques',
	'label_credits' => 'Crédits',
	'label_fichier' => 'Fichier',
	'label_fichier_vignette' => 'Vignette',
	'label_paginer_par' => 'Paginer par :',
	'label_parents' => 'Ce document est lié à',
	'label_refdoc_joindre' => 'Document numéro',
	'label_titre_mimetype' => 'Type de fichier',
	'lien_tout_desordonner' => 'Réinitialiser l’ordre',
	'lien_tout_desordonner_verif' => 'L’ordre définit pour cette liste de documents sera réinitialisé. Es-tu sûr ?',
	'lien_tout_enlever' => 'Tout détacher',
	'lien_tout_enlever_verif' => 'Veux-tu détacher tous les documents ?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Bandes-son',
	'media_file' => 'Autres',
	'media_image' => 'Images',
	'media_video' => 'Séquences',
	'miniature_automatique_active' => 'SPIP génèrera automatiquement une miniature de l’image',

	// N
	'nb_documents_attache_succes' => '@nb@ documents ont bien été ajoutés',
	'nb_documents_installe_succes' => '@nb@ fichiers chargés avec succès',

	// O
	'objet_document' => 'Document',
	'objet_documents' => 'Documents',
	'ordonner_ce_document' => 'Ordonner ce document',

	// P
	'par_date' => 'Date',
	'par_hauteur' => 'Hauteur',
	'par_id' => 'ID',
	'par_largeur' => 'Largeur',
	'par_taille' => 'Poids',
	'par_titre' => 'Titre',

	// T
	'texte_documents_joints' => 'Tu peux activer l’interface d’ajout de documents (fichiers bureautiques, images, multimédia, etc.) aux articles, rubriques et autres. Ces fichiers peuvent ensuite être référencés dans le texte, ou affichés séparément.',
	'texte_documents_joints_2' => 'Ce réglage n’empêche pas le téléversement d’images dans les articles ni l’insertion de document directement dans les textes des contenus.',
	'titre_documents_joints' => 'Documents joints',
	'titre_page_documents_edit' => 'Modifier le document : @titre@',
	'tous_les_medias' => 'Tous les médias',
	'tout_dossier_upload' => 'Tout le dossier @upload@',
	'tout_voir' => 'Tout voir',

	// U
	'un_audio' => '1 bande-son',
	'un_document' => '1 document',
	'un_file' => '1 document',
	'un_image' => '1 image',
	'un_video' => '1 séquence',
	'une_utilisation' => '1 utilisation',
	'upload_fichier_zip' => 'Fichier ZIP',
	'upload_fichier_zip_texte' => 'Le fichier que tu proposes d’installer est un fichier Zip.',
	'upload_fichier_zip_texte2' => 'Ce fichier peut être :',
	'upload_info_mode_document' => 'Déposer dans le portfolio',
	'upload_info_mode_image' => 'Retirer du portfolio',
	'upload_limit' => 'Ce fichier est trop gros pour le serveur ; la taille maximum autorisée en <i>upload</i> est de @max@.',
	'upload_zip_conserver' => 'Conserver l’archive après extraction',
	'upload_zip_decompacter' => 'décompressé et chaque élément qu’il contient installé sur le site. Les fichiers qui seront alors installés sur le site sont :',
	'upload_zip_mode_document' => 'Déposer toutes les images dans le portfolio',
	'upload_zip_telquel' => 'installé tel quel, en tant qu’archive compressée Zip ;',
	'upload_zip_titrer' => 'Titrer selon le nom des fichiers',

	// V
	'verifier_documents_brises' => 'Vérifier les fichiers manquants',
	'verifier_documents_inutilises' => 'Vérifier les liens des documents',
	'vignette_supprimee' => 'La vignette a été supprimée',
];
